Crate yew_transition_group

Crate yew_transition_group 

yew-transition-group provides components that manage transitions for child components

Structs

Timeout
The timeout is a way to specify One timeout or different timeouts for appear, enter, exit.
Transition
A component that wraps other components and handles transitions, making available TransitionState to the wrapped children.
TransitionProps
The Props for Transition.

Enums

TransitionState
The four states that the children components see.