yew-transition-group provides components that manage transitions for child components
Structs
- Timeout
- The timeout is a way to specify One timeout or different timeouts for appear, enter, exit.
- Transition
- A component that wraps other components and handles transitions, making available
TransitionStateto the wrapped children. - Transition
Props - The Props for Transition.
Enums
- Transition
State - The four states that the children components see.